@@ -70,7 +70,6 @@ def parse(
     ignore_case: bool = False, 
     check_mimetype: bool = False, 
 ) -> Optional[Callable[[str], bool]]:
-    check_pass = lambda s: s in ("*", "*/") or "**" in s and not s.strip("*/")
     shows: list[str] = []
     show_all: bool = False
     ignores: list[str] = []
@@ -86,11 +85,8 @@ def parse(
                 continue
             pattern = pattern[1:]
             if pattern:
-                if check_pass(pattern):
-                    if pattern.endswith("/"):
-                        ignores.append("*/")
-                    else:
-                        ignore_all = True
+                if pattern == "*":
+                    ignore_all = True
                 else:
                     ignores.append(pattern)
         elif check_mimetype and pattern.removeprefix("!").startswith(
@@ -107,21 +103,15 @@ def parse(
                 continue
             pattern = pattern[1:]
             if pattern:
-                if check_pass(pattern):
-                    if pattern.endswith("/"):
-                        shows.append("*/")
-                    else:
-                        show_all = True
+                if pattern == "*":
+                    show_all = True
                 else:
                     shows.append(pattern)
         else:
             if ignore_all:
                 continue
-            if check_pass(pattern):
-                if pattern.endswith("/"):
-                    ignores.append("*/")
-                else:
-                    ignore_all = True
+            if pattern == "*":
+                ignore_all = True
             else:
                 ignores.append(pattern)
     if show_all:
